@@ -382,7 +382,7 @@ class ParametersCOSIM:
                 for j in range(2):  # 2Ports in PSpice
                     struct = {}
                     struct["name"] = "Port_" + str(i+n*len(CoilSections)+1) + "_" + str(j)
-                    struct["components"] = [LSections(i)]
+                    struct["components"] = [LSections[i]]
                     struct["inputs"] = []
                     for l in range(len(couplingParameterPSpice[j][0])):  # Number of In's
                         substruct_in = {}
